@@ -1,9 +1,12 @@
 ## ----setup, include=FALSE-----------------------------------------------------
-library(INLA)
 set.seed(123)
+library(INLA)
 inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
+inla.setOption(inla.mode="experimental")
+if (file.exists("myinit.R")) source("myinit.R")
 knitr::opts_chunk$set(echo = TRUE)
+knitr::opts_chunk$set(fig.path="figures/multinomial/")
 
 ## ---- message = FALSE, warning = FALSE----------------------------------------
 # number of observations 
